@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2014 Dave M
+# ClamTk, copyright (C) 2004-2015 Dave M
 #
 # This file is part of ClamTk (http://code.google.com/p/clamtk/)
 #
@@ -105,7 +105,6 @@ sub show_window {
 
     my $label = Gtk2::Label->new;
     $label->set_text( $text );
-    $label->set_alignment( 0.0, 0.5 );
     $infobar->get_content_area()->add( $label );
     #<<<
     $infobar->signal_connect(
@@ -153,7 +152,6 @@ sub get_remote_TK_version {
 }
 
 sub update_signatures {
-
     $pb->{ timer } = Glib::Timeout->add( 100, \&progress_timeout, $pb );
     $pb->show;
     #$pb->set_show_text( TRUE );
@@ -232,7 +230,7 @@ sub update_signatures {
 
     # Update infobar type and text; remove button
     Gtk2->main_iteration while Gtk2->events_pending;
-    set_infobar_text( 'info', _( '' ) );
+    set_infobar_text( 'info', '' );
     ClamTk::GUI::set_infobar_mode( 'info', '' );
     # $pb->hide;
     # destroy_button();
